@@ -12,8 +12,7 @@ sub root :Chained(/) PathPart('') CaptureArgs(0) ($self, $c) { }
     return $c->detach_error(404, +{error=>"Requested URL not found: @{[ $c->req->uri ]}"});
   }
 
-  sub static :GET Chained(root) PathPart('static') Args {
-    my ($self, $c, @args) = @_;
+  sub static :GET Chained(root) PathPart('static') Args ($self, $c, @args) {
     return $c->serve_file('static', @args) // $c->detach_error(404, +{error=>"Requested URL not found: @{[ $c->req->uri ]}"});
   }
 
@@ -23,7 +22,7 @@ sub root :Chained(/) PathPart('') CaptureArgs(0) ($self, $c) { }
   
   sub auth :Chained(root) PathPart('') CaptureArgs() ($self, $c) {
     return $c->next_action($c->user) if $c->user->authenticated;
-    return $c->detach('#login'); 
+    return $c->redirect_to_action('#login', +{post_login_redirect=>$c->req->uri}) && $c->detach;
   }
 
 sub end :Action Does(RenderErrors) Does(RenderView) { }  # The order of the Action Roles is important!!
