@@ -6,18 +6,16 @@ use Example::Syntax;
 
 extends 'Example::Controller';
 
-sub login : Chained(../root) Args(0) Verbs(GET,POST) Name(login) ($self, $c) {
+sub login : Chained(../root) Args(0) Verbs(GET,POST) Name(login) RequestModel(LoginQuery) ($self, $c, $q) {
   $c->redirect_to_action('#home') && $c->detach if $c->user->authenticated; # Don't bother if already logged in
   $c->view('HTML::Login', user => $c->user);
+  $c->view->post_login_redirect($q->post_login_redirect) if $q->has_post_login_redirect;
+  $c->next_action($q);
 }
 
-  sub POST :Action RequestModel(LoginRequest) ($self, $c, $request) {
-    $c->view->post_login_redirect($request->post_login_redirect)
-      if $request->has_post_login_redirect;
-
+  sub POST :Action RequestModel(LoginRequest) ($self, $c, $request, $q) {
     return $c->view->set_http_bad_request unless $c->authenticate($request->person);
-    return $c->res->redirect($request->post_login_redirect) if $request->has_post_login_redirect;
-    return $c->res->redirect($c->req->uri) if $c->action ne $self->action_for('login');  # ->detach case from the auth action
+    return $c->res->redirect($q->post_login_redirect) if $q->has_post_login_redirect;
     return $c->redirect_to_action('#home');
   }
 
