@@ -3,7 +3,7 @@ package Example::Schema::ResultSet::Todo;
 use Example::Syntax;
 use base 'Example::Schema::ResultSet';
 
-__PACKAGE__->mk_group_accessors('simple' => qw/query/);
+__PACKAGE__->mk_group_accessors('simple' => qw/status/);
 
 sub available($self) {
   return $self->search_rs({status=>{'!='=>'archived'}});
@@ -15,10 +15,8 @@ sub newer_first($self) {
 sub filter_by_request($self, $request) {
   my $todos = $request->status_all ?
     $self : $self->search_rs({status=>$request->status});
-
-  $todos = $todos->page($request->page);
-  $todos->query($request);
-
+  $todos = $todos->page_or_last($request->page); 
+  $todos->status($request->status);
   return $todos;
 }
 
