@@ -11,9 +11,7 @@ has info => (is=>'rw', predicate=>'has_info');
 sub render($self, $c) {
   $c->view('HTML::Layout' => page_title=>'Homepage', sub($layout) {
     $c->view('HTML::Navbar' => active_link=>'/'),
-    cond { $self->has_info } sub {
-      blockquote +{ class=>"alert alert-primary", role=>"alert" }, $self->info,
-    },
+    blockquote +{ cond=>$self->has_info, class=>"alert alert-primary", role=>"alert" }, $self->info,
     div 'Welcome to your Example application Homepage';
   });
 }
