@@ -14,9 +14,15 @@ __PACKAGE__->views(
   form_for => 'HTML::FormFor',
 );
 
+sub action_link($self) {
+  return $self->has_post_login_redirect ?
+    $self->ctx->uri('#login', +{post_login_redirect=>$self->post_login_redirect}) :
+    $self->ctx->uri('#login');
+}
+
 sub render($self, $c) {
   $self->layout(page_title => 'Sign In', sub($layout) {
-    $self->form_for($self->user, +{action_bak=>$c->uri('#login'), class=>'mx-auto', style=>'width:25em'}, sub ($ff, $fb, $u) {
+    $self->form_for($self->user, +{action=>$self->action_link, class=>'mx-auto', style=>'width:25em'}, sub ($ff, $fb, $u) {
       fieldset [
         legend 'Sign In',
         div +{ class=>'form-group' },
